@@ -24,7 +24,7 @@ except ImportError:
 TEXT_ENDPOINT = "https://api.houndify.com/v1/text"
 VOICE_ENDPOINT = "https://api.houndify.com/v1/audio"
 TRANSCRIPTION_ENDPOINT = "https://transcription.houndify.com/v1/transcription"
-VERSION = "2.0.12"
+VERSION = "2.0.13"
 
 
 class HoundifySDKError(Exception):
@@ -189,29 +189,46 @@ class HoundListener(object):
     def onPartialTranscript(self, transcript):
       """
       onPartialTranscript is fired when the server has sent a partial transcript
-      in live transcription mode.  "transcript" is a string with the partial transcript
+      in live transcription mode.  "transcript" is a string with the partial transcript.
       """
       pass
     def onFinalPartialTranscript(self, transcript):
       """
-      onFinalPartialTranscript is fired once the server has identified more
-      than 2 complete sentences. The first sentence can migrate to final
+      onFinalPartialTranscript is fired once the server has identified one or more
+      complete sentences that are guaranteed not to change in the future.
+      These sentences won't be included in partial transcripts going forward,
+      the client needs to accumulate them in order to compile the full transcript.
+      Only occurs in live transcription mode.
       """
       pass
     def onEntityIdentification(self, entities, transcript):
+      """
+      onEntityIdentification is fired once the server has detected an entity.
+      """
       pass
     def onTopicIdentification(self, topics, transcript):
-      pass
-    def onPartialTranscriptTokens(self, transcript):
       """
-      onPartialTranscriptTokens is fired when the server has a partial transcript.
+      onTopicIdentification is fired once the server has detected a topic.
       """
       pass
-    def onFinalPartialTranscriptTokens(self, transcript):
+    def onPartialTranscriptProperties(self, transcript, props):
       """
-      onFinalPartialTranscriptTokens is fired once the server has identified more
-      than 2 complete sentences and contains more detailed information about each
-      FinalPartialTranscript received.
+      onPartialTranscriptProperties is fired when the server has a partial transcript
+      and detailed information is provided by the server (usually in live transcription
+      mode). "props" is a HoundTranscriptProperties JSON object (as a Python dict)
+      containing the "Tokens" array and optional extra fields such as "TopicIdentification"
+      or "EntityDetection".
+      """
+      pass
+    def onFinalPartialTranscriptProperties(self, transcript, props):
+      """
+      onFinalPartialTranscriptProperties is fired once the server has identified one
+      or more complete sentences that are guaranteed not to change in the future.
+      These sentences won't be included in partial transcripts going forward,
+      the client needs to accumulate them in order to compile the full transcript.
+      "props" is a HoundTranscriptProperties JSON object (as a Python dict)
+      containing the "Tokens" array and optional extra fields such as "TopicIdentification"
+      or "EntityDetection". Only occurs in live transcription mode.
       """
       pass
     def onFinalResponse(self, response):
@@ -463,21 +480,11 @@ class StreamingHoundClient(_BaseHoundClient):
               except:
                 pass
               try:
-                if len(parsedMsg["EntityDetection"]) > 0:
-                  listener.onEntityIdentification(parsedMsg["EntityDetection"], parsedMsg["FinalPartialTranscriptTokens"])
+                listener.onFinalPartialTranscriptProperties(parsedMsg["FinalPartialTranscript"], parsedMsg["FinalPartialTranscriptProperties"])
               except:
                 pass
               try:
-                if len(parsedMsg["TopicIdentification"]) > 0:
-                  listener.onTopicIdentification(parsedMsg["TopicIdentification"], parsedMsg["FinalPartialTranscriptTokens"])
-              except:
-                pass
-              try:
-                listener.onPartialTranscriptTokens(parsedMsg["PartialTranscriptTokens"])
-              except:
-                pass
-              try:
-                listener.onFinalPartialTranscriptTokens(parsedMsg["FinalPartialTranscriptTokens"])
+                listener.onPartialTranscriptProperties(parsedMsg["PartialTranscript"], parsedMsg["PartialTranscriptProperties"])
               except:
                 pass
               listener.onPartialTranscript(parsedMsg["PartialTranscript"])
